==> p5-Curses-UI-0.74.tgz: libdata/perl5/site_perl/Curses/UI/Language/polish.pm <==
# ----------------------------------------------------------------------
# Curses::UI::Language::polish
# Maintainer: akukula@interia.pl
# ----------------------------------------------------------------------

package Curses::UI::Language::polish; 
1;
__DATA__

# ----------------------------------------------------------------------
# For Curses::UI
# ----------------------------------------------------------------------

[screen_too_small]
Rozmiar twojego ekranu jest zbyt may dla tej aplikacji.
Zmie rozmiar ekranu i uruchom ponownie aplikacj.
NAcinij <CTRL+C> aby zakoczy...

# ----------------------------------------------------------------------
# For Curses::UI::Calendar
# ----------------------------------------------------------------------

[months]
Stycze Luty Marzec Kwiecie Maj Czerwiec Lipiec 
Sierpie Wrzesie Padziernik Listopad Grudzie

[days_short] Ni Po Wt r Cz Pi So

# ----------------------------------------------------------------------
# For Curses::UI::Buttonbox
# ----------------------------------------------------------------------

[button_ok]      o:OK
[button_cancel]  a:Anuluj
[button_yes]     t:Tak
[button_no]      n:Nie

# ----------------------------------------------------------------------
# For Curses::UI::Dialog::Error
# ----------------------------------------------------------------------

[error_title]    Komunikat o bdzie

# ----------------------------------------------------------------------
# For Curses::UI::Dialog::FileBrowser
# ----------------------------------------------------------------------

# The filebrowser title
[file_title]     Wybierz plik
[file_savetitle] Wybierz plik do zapisu
[file_loadtitle] Wybierz plik do odczytu

# The labels for the dialog screen.
[file_path]      cieka :
[file_file]      Plik :
[file_mask]      Maska :

# The size of the longest label
[file_labelsize] 9

# On directory up
[file_dirup] Katalog nadrzdny

# For asking the user if a file may be overwritten
[file_overwrite_title] Potwierdzenie
[file_overwrite_question_pre] 
Plik "
[file_overwrite_question_post] 
" ju istnieje. Czy chcesz zamieni istniejcy plik?

# Errors
[file_err_opendir_pre] Nie mona otworzy katalogu "
[file_err_opendir_post] "
[file_err_nofileselected] Nie wybrano pliku!

==> p5-Curses-UI-0.9609p1.tgz: libdata/perl5/site_perl/Curses/UI/Language/polish.pm <==
# ----------------------------------------------------------------------
# Curses::UI::Language::polish
# Maintainer: ak@min.pl
# ----------------------------------------------------------------------

package Curses::UI::Language::polish; 
1;
__DATA__

# ----------------------------------------------------------------------
# For Curses::UI
# ----------------------------------------------------------------------

[screen_too_small]
Rozmiar twojego ekranu jest zbyt may dla tej aplikacji.
Zmie rozmiar ekranu i uruchom ponownie aplikacj.
Nacinij <CTRL+C> aby zakoczy...

# ----------------------------------------------------------------------
# For Curses::UI::Calendar
# ----------------------------------------------------------------------

[months]
Stycze Luty Marzec Kwiecie Maj Czerwiec Lipiec 
Sierpie Wrzesie Padziernik Listopad Grudzie

[days_short] Ni Po Wt r Cz Pi So

# ----------------------------------------------------------------------
# For Curses::UI::Buttonbox
# ----------------------------------------------------------------------

[button_ok]      o:OK
[button_cancel]  a:Anuluj
[button_yes]     t:Tak
[button_no]      n:Nie

# ----------------------------------------------------------------------
# For Curses::UI::Dialog::Error
# ----------------------------------------------------------------------

[error_title]    Komunikat o bdzie

# ----------------------------------------------------------------------
# For Curses::UI::Dialog::FileBrowser
# ----------------------------------------------------------------------

# The filebrowser title
[file_title]     Wybierz plik
[file_savetitle] Wybierz plik do zapisu
[file_loadtitle] Wybierz plik do odczytu

# The labels for the dialog screen.
[file_path]      cieka :
[file_file]      Plik :
[file_mask]      Maska :

# The size of the longest label
[file_labelsize] 9

# On directory up
[file_dirup] Katalog nadrzdny

# For asking the user if a file may be overwritten
[file_overwrite_title] Potwierdzenie
[file_overwrite_question_pre] 
Plik "
[file_overwrite_question_post] 
" ju istnieje. Czy chcesz zamieni istniejcy plik?

# Errors
[file_err_opendir_pre] Nie mona otworzy katalogu "
[file_err_opendir_post] "
[file_err_nofileselected] Nie wybrano pliku!
